Learn R Programming

GrammR (version 1.1.0)

metagencounts: Randomly generated Metagenomic Counts

Description

This data comprises random metagenomic counts generated using simulation model II described in the reference below. The counts are recorded for a total of 80 samples over 200 taxa. The 80 samples are divided into eight communities of equal size.

Usage

data(metagencounts)

Arguments

Format

data.frame

References

Ayyala, D. N., Lin, S., (2015) GrammR: graphical representation and modeling of count data with application in metagenomics, Bioinformatics, 31(10)